@@ -10,5 +10,4 @@ except DistributionNotFound:
 finally:
     del get_distribution, DistributionNotFound
 
-# django
-default_app_config = "django_project_backup.apps.DjangoProjectBackupApp"
+default_app_config = 'django_project_backup.apps.DjangoProjectBackupConfig'
