@@ -2,7 +2,7 @@ from django.core.management.base import BaseCommand  # , CommandError
 from django.utils import timezone
 
 from ...utils.filesystem import run_private_assets_backup, run_public_assets_backup
-from ...settings import DJANGO_PROJECT_BACKUP_DESTINATION_FOLDER
+from ...settings import BACKUP_DESTINATION_FOLDER
 
 
 class Command(BaseCommand):
@@ -28,7 +28,7 @@ class Command(BaseCommand):
                     return
 
             self.stdout.write(
-                self.style.SUCCESS('Assets backup done into "{}"'.format(DJANGO_PROJECT_BACKUP_DESTINATION_FOLDER)))
+                self.style.SUCCESS('Assets backup done into "{}"'.format(BACKUP_DESTINATION_FOLDER)))
 
         except Exception as e:
             self.stdout.write(self.style.ERROR('Error executing assets backup: {}'.format(e)))
