@@ -4,7 +4,7 @@ from django.core.management import call_command
 
 from unittest.mock import patch
 
-from ...settings import DJANGO_PROJECT_BACKUP_EXCLUDED_MODELS
+from ...settings import SERIALIZATION_MODULE, EXCLUDED_MODELS
 from .adapter import DBAdapter
 from .stream import CouchdbStream
 
@@ -27,8 +27,8 @@ def dumpdata():
 
         # dump to FS
         options = {
-            'format': 'couchdb_datastore',
-            'exclude': DJANGO_PROJECT_BACKUP_EXCLUDED_MODELS,
+            'format': SERIALIZATION_MODULE,
+            'exclude': EXCLUDED_MODELS,
             'output': stream.get_output_name(),
             'use_natural_foreign_keys': True,
             'verbosity': 0
@@ -64,7 +64,7 @@ def loaddata():
     stream = CouchdbStream()
 
     options = {
-        'exclude': DJANGO_PROJECT_BACKUP_EXCLUDED_MODELS,
+        'exclude': EXCLUDED_MODELS,
         'verbosity': 0
     }
 
