@@ -1,3 +1,4 @@
+import logging
 import json
 import datetime
 
@@ -9,6 +10,8 @@ from cloudant.error import CloudantDatabaseException
 from ...settings import COUCHDB_DATASTORE_USER, COUCHDB_DATASTORE_PASSWORD, COUCHDB_DATASTORE_URL, \
                         COUCHDB_DATASTORE_DATABASE_NAME, BACKUP_MODE
 
+logger = logging.getLogger('django_project_backup.utils.couchdb.adapter')
+
 
 def response_to_json_dict(response, **kwargs):
     """
@@ -84,7 +87,17 @@ class DBAdapter:
                 doc['_rev'] = existing_rev
 
                 _updated = self.put_documents([doc])
-                updated = len(list(filter(lambda x: x['ok'], filter(lambda x: x['id'] == doc['_id'], _updated)))) == 1
+                logger.debug('Couchdb reponse: {}'.format(_updated))
+
+                update_status = list(filter(lambda x: x['id'] == doc['_id'], _updated))[0]
+
+
+                error_status = update_status.get('error', None)
+
+                success_status = update_status.get('ok', error_status is not None and \
+                                                         error_status == 'conflict')
+
+                updated = success_status
 
             return updated
 
