@@ -17,6 +17,7 @@ class Serializer(JSONSerializer):
         except AttributeError:
             object_id = obj.pk
 
-        dump_object['_id'] = '{}:{}'.format(dump_object['model'], object_id)
+        dump_object_id = '{}:{}'.format(dump_object['model'], object_id)
+        dump_object['_id'] = dump_object_id
 
         return dump_object
